@@ -27,17 +27,17 @@ def store():
     yield _store
 
 
-def pytest_sessionfinish(session, exitstatus):
+def pytest_terminal_summary(terminalreporter, exitstatus, config):
     """Print our benchmark results (if present)."""
-    if any([len(_store[key]) for key in _store]):
-        from py.io import TerminalWriter
-        writer = TerminalWriter()
-        writer.line()  # newline
-        writer.sep('=', 'benchmark results')
-        for type_name, results in _store.items():
-            writer.sep('-', type_name)
-            for name, vals in results.items():
-                writer.line(
-                    f'{name}:\n'
-                    f'    Horizontal: {vals["h"]:6.2f}\n'
-                    f'    Vertical:   {vals["v"]:6.2f}')
+    if not any(len(_store[key]) for key in _store):
+        return
+    writer = terminalreporter
+    writer.line('')  # newline
+    writer.write_sep('=', 'benchmark results')
+    for type_name, results in _store.items():
+        writer.write_sep('-', type_name)
+        for name, vals in results.items():
+            writer.line(
+                f'{name}:\n'
+                f'    Horizontal: {vals["h"]:6.2f}\n'
+                f'    Vertical:   {vals["v"]:6.2f}')
